@@ -7,7 +7,7 @@ import tree_sitter as ts
 import tree_sitter_zig
 
 CODE_BLOCK_PATTERN = re.compile(
-    r"```(?:([A-Za-z0-9\-_\+\.#]+)\n+([^\n].+?)|(.*?))```", re.DOTALL
+    r"```(?:([A-Za-z0-9\-_\+\.#]+)(?:\r?\n)+([^\r\n].*?)|(.*?))```", re.DOTALL
 )
 
 ZIG_PARSER = ts.Parser(ts.Language(tree_sitter_zig.language()))
@@ -26,19 +26,20 @@ class CodeBlock(NamedTuple):
     body: str
 
 
-def extract_codeblocks(source: str) -> Iterator[CodeBlock]:
-    """Yield CodeBlocks from a Markdown source."""
+def extract_codeblocks(source: str | bytes) -> Iterator[CodeBlock]:
+    """Yield CodeBlocks from a Markdown source. Assumes UTF-8 if source is `bytes`."""
+    if isinstance(source, bytes):
+        source = source.decode()
     for m in CODE_BLOCK_PATTERN.finditer(source):
         lang, body, no_lang_body = m.groups()
         yield (
-            CodeBlock(lang, body=body.strip("\n"))
+            CodeBlock(lang, body=body.strip("\r\n"))
             if lang
-            else CodeBlock(lang=None, body=no_lang_body.strip("\n"))
+            else CodeBlock(lang=None, body=no_lang_body.strip("\r\n"))
         )
 
 
-def tokenize_zig(source: str) -> Iterator[Token]:
-    src = source.encode()
+def tokenize_zig(src: bytes) -> Iterator[Token]:
     tree = ZIG_PARSER.parse(src)
     return _traverse(tree.root_node, src)
 
